/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.persistence.config;

import java.net.URL;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Properties;

import javax.persistence.spi.ClassTransformer;
import javax.persistence.spi.PersistenceUnitInfo;
import javax.persistence.spi.PersistenceUnitTransactionType;
import javax.sql.DataSource;

import org.apithefire.util.lang.Objects;

class PersistenceUnitInfoImpl implements PersistenceUnitInfo {

	private final String providerClassName;
	private final List<String> managedClassNames;
	private final Properties properties;
	
	public PersistenceUnitInfoImpl(String providerClassName,
			List<String> managedClassNames, Properties properties) {
		this.providerClassName = Objects.nonNull(providerClassName);
		this.managedClassNames = new ArrayList<String>(managedClassNames);
		this.properties = new Properties(properties);
	}

	public String getPersistenceProviderClassName() {
		return providerClassName;
	}

	public List<String> getManagedClassNames() {
		return managedClassNames;
	}

	public Properties getProperties() {
		return properties;
	}

	public DataSource getNonJtaDataSource() {
		return null;
	}

	public void addTransformer(ClassTransformer transformer) {
		// TODO: what to do with this?
	}

	public String getPersistenceUnitName() {
		return toString();
	}

	public boolean excludeUnlistedClasses() {
		return true;
	}

	public ClassLoader getClassLoader() {
		return ClassLoader.getSystemClassLoader();
	}

	public List<URL> getJarFileUrls() {
		return Collections.emptyList();
	}

	public DataSource getJtaDataSource() {
		return null;
	}

	public List<String> getMappingFileNames() {
		return Collections.emptyList();
	}

	public ClassLoader getNewTempClassLoader() {
		return ClassLoader.getSystemClassLoader();
	}

	public URL getPersistenceUnitRootUrl() {
		return null;
	}

	public PersistenceUnitTransactionType getTransactionType() {
		return PersistenceUnitTransactionType.RESOURCE_LOCAL;
	}

}
